@@ -142,6 +142,7 @@ static void
 cc_notifications_panel_init (CcNotificationsPanel *panel)
 {
   GtkWidget *w;
+  GtkWidget *label;
   GError *error = NULL;
 
   g_resources_register (cc_notifications_get_resource ());
@@ -184,8 +185,17 @@ cc_notifications_panel_init (CcNotificationsPanel *panel)
                                 cc_list_box_update_header_func,
                                 NULL, NULL);
 
+  label = GTK_WIDGET (gtk_builder_get_object (panel->builder,
+                                              "label1"));
   w = GTK_WIDGET (gtk_builder_get_object (panel->builder,
                                           "ccnotify-app-listbox"));
+  atk_object_add_relationship (ATK_OBJECT (gtk_widget_get_accessible (label)),
+                               ATK_RELATION_LABEL_FOR,
+                               ATK_OBJECT (gtk_widget_get_accessible (w)));
+  atk_object_add_relationship (ATK_OBJECT (gtk_widget_get_accessible (w)),
+                               ATK_RELATION_LABELLED_BY,
+                               ATK_OBJECT (gtk_widget_get_accessible (label)));
+
   panel->sections = g_list_append (panel->sections, w);
   panel->sections_reverse = g_list_prepend (panel->sections_reverse, w);
   g_signal_connect (w, "keynav-failed", G_CALLBACK (keynav_failed), panel);
@@ -255,8 +265,13 @@ add_application (CcNotificationsPanel *panel,
 {
   GtkWidget *box, *w, *row, *list_box;
   GIcon *icon;
+  const gchar *app_name;
   int size;
 
+  app_name = g_app_info_get_name (app->app_info);
+  if (app_name == NULL || *app_name == '\0')
+    return;
+
   icon = g_app_info_get_icon (app->app_info);
   if (icon == NULL)
     icon = g_themed_icon_new ("application-x-executable");
@@ -281,10 +296,11 @@ add_application (CcNotificationsPanel *panel,
   gtk_widget_set_margin_start (w, 12);
   gtk_widget_set_margin_top (w, 8);
   gtk_widget_set_margin_bottom (w, 8);
+  gtk_size_group_add_widget (GTK_SIZE_GROUP (gtk_builder_get_object (panel->builder, "sizegroup1")), w);
   gtk_container_add (GTK_CONTAINER (box), w);
   g_object_unref (icon);
 
-  w = gtk_label_new (g_app_info_get_name (app->app_info));
+  w = gtk_label_new (app_name);
   gtk_container_add (GTK_CONTAINER (box), w);
 
   w = gtk_label_new ("");
