@@ -680,7 +680,6 @@ group_physical_devices_cb (gchar    ***device_uris,
           /* Is there any device in this sublist? */
           if (device_uris[i][0] != NULL)
             {
-              device = NULL;
               for (j = 0; device_uris[i][j] != NULL; j++)
                 {
                   device = device_in_list (device_uris[i][j], priv->devices);
@@ -1317,11 +1316,7 @@ parse_uri (const gchar  *uri,
       *port = atoi (position + 1);
     }
 
-  *host = g_uri_unescape_string (resulting_host,
-                                 G_URI_RESERVED_CHARS_GENERIC_DELIMITERS
-                                 G_URI_RESERVED_CHARS_SUBCOMPONENT_DELIMITERS);
-
-  g_free (resulting_host);
+  *host = resulting_host;
 
   return TRUE;
 }
@@ -1738,6 +1733,18 @@ cups_get_dests_cb (GObject      *source_object,
     }
 }
 
+static void
+row_activated_cb (GtkTreeView       *tree_view,
+                  GtkTreePath       *path,
+                  GtkTreeViewColumn *column,
+                  gpointer           user_data)
+{
+  PpNewPrinterDialog        *dialog = (PpNewPrinterDialog *) user_data;
+  PpNewPrinterDialogPrivate *priv = dialog->priv;
+
+  gtk_dialog_response (GTK_DIALOG (priv->dialog), GTK_RESPONSE_OK);
+}
+
 static void
 cell_data_func (GtkTreeViewColumn  *tree_column,
                 GtkCellRenderer    *cell,
@@ -1812,6 +1819,9 @@ populate_devices_list (PpNewPrinterDialog *dialog)
   g_signal_connect (gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview)),
                     "changed", G_CALLBACK (device_selection_changed_cb), dialog);
 
+  g_signal_connect (treeview,
+                    "row-activated", G_CALLBACK (row_activated_cb), dialog);
+
   priv->local_printer_icon = g_themed_icon_new ("printer");
   priv->remote_printer_icon = g_themed_icon_new ("printer-network");
 
